#
# spec file for package lcms
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lcms
Summary:        Utilities for the Little CMS Engine
License:        MIT
Group:          Productivity/Graphics/Other
Url:            http://www.littlecms.com/
Version:        1.19
Release:        22.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        http://downloads.sourceforge.net/project/%{name}/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch:          lcms-endian.patch
Patch1:         lcms-strict-aliasing.patch
Patch2:         lcms-implicit-declaration.patch
# PATCH-FIX-SECURITY CVE-2013-4276.patch bnc843716 sbrabec@suse.cz -- Stack overflow fix.
Patch3:         CVE-2013-4276.patch

%if 0%{?fedora_version}   
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  zlib-devel
%endif 
%if 0%{?suse_version}  
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  zlib-devel
%endif 

# bug437293
%ifarch ppc64
Obsoletes:      liblcms-64bit
%endif

%description
Little cms is a small speed optimized color management engine.

%package -n liblcms1
Summary:        Libraries for the Little CMS Engine
Group:          System/Libraries
#workaround for wrong package naming
Provides:       liblcms0 = %{version}
Obsoletes:      liblcms0 <= %{version}

%description -n liblcms1
Little cms is a small speed optimized color management engine.

%package -n liblcms-devel
Summary:        Include Files and Libraries Mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       liblcms1 = %{version}
# bug437293
%ifarch ppc64
Obsoletes:      liblcms-devel-64bit
%endif
#

%description -n liblcms-devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package -n python-lcms
Summary:        Python Bindings for the Little CMS Engine
Group:          Development/Libraries/Python
%if 0%{?suse_version}
%py_requires
%endif
%if 0%{?fedora_version}
Requires:       python
%endif

%description -n python-lcms
Little cms is a small speed optimized color management engine.

%prep
%setup -q
%patch
%patch1
%patch2
%patch3 -p1
cp -a README.1ST README
chmod -x COPYING AUTHORS NEWS README doc/*.TXT

%build
%configure\
	--disable-static\
	--with-python
make  %{?_smp_flags}

%check
make check

%install
%makeinstall
rm $RPM_BUILD_ROOT%{_libdir}/*.la $RPM_BUILD_ROOT%{py_sitedir}/_lcms.la

%post -n liblcms1 -p /sbin/ldconfig

%postun -n liblcms1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING AUTHORS NEWS README
%{_bindir}/*
%{_mandir}/man?/*.*

%files -n liblcms1
%defattr(-,root,root)
%{_libdir}/liblcms.so.1*

%files -n liblcms-devel
%defattr(-,root,root)
%doc doc/*.TXT
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n python-lcms
%defattr(-,root,root,-)
%{py_sitedir}/lcms.py*
%{py_sitedir}/_lcms.so

%changelog
* Wed Dec  4 2013 mls@suse.de
- adapt lcms-endian patch to ppc64le
* Sat Oct  5 2013 crrodriguez@opensuse.org
- add zlib-devel to buildrequires, not implicit anymore.
* Fri Oct  4 2013 sbrabec@suse.cz
- Stack overflow fix
  (CVE-2013-4276.patch, bnc#843716, CVE-2013-4276).
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Kill liblcms1->lcms Requires (the library does not depend on
  the tools)
* Sun Oct 10 2010 mrdocs@opensuse.org
- version bump to 1.19 which includes:
  + fixed minor vulnerabilities mentioned in NEWS file
  + removed cosmetic comparation with zero in floating point
  + no API changes
- drop lcms-bnc521513.patch - the change is in 1.19
* Mon May 17 2010 coolo@novell.com
- do not re-swig, it's just too expensive as buildrequire
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Jul 14 2009 sbrabec@suse.cz
- Fix of incorrect GrayTRC (CVE-2009-0793) fix (bnc#521513).
* Thu Jul  9 2009 sbrabec@suse.cz
- Updated to fixed version 1.18a:
  * Don't crash on missing GrayTRC.
* Mon Apr  6 2009 wstephenson@suse.de
- Updated to version 1.18
  * Changes in API:
  * None
  * Implementation:
  * Vulnerability fixes on all code.
  * Status check, many functions now check the status when
    calling other functions.  Improved robustness against
    ill-formed profiles.
  * Utilities
  * icctrans: fixed wrongly implemented CMYKcm support.
  * icclink: fixed linking 3 to 7 channels.
* Thu Jan 29 2009 olh@suse.de
- fix obsolete liblcms-XXbit name, obsolete also the -devel package
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Jul  1 2008 sbrabec@suse.cz
- Enabled python-lcms bindings (bnc#371592).
* Tue Jun  3 2008 coolo@suse.de
- require COPYING package
* Sun May 11 2008 coolo@suse.de
- fix renames of xxbit packages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Dec 26 2007 crrodriguez@suse.de
- fix E: shlib-policy-name-error (Badness: 10000) liblcms1
- disable static libraries and remove libtool archives
* Mon Nov  5 2007 sbrabec@suse.cz
- Provide and obsolete old package name.
- gcc warning fixes.
* Thu Nov  1 2007 sbrabec@suse.cz
- Updated to version 1.17 (#276528):
  * Changes in API:
  * several functions wrapped
  * cmsSetLanguage parameters changed to match ICC spec
  * removed support for extended gamut descriptor
  * cmsFLAGS_NODEFAULTRESOURCEDEF moved to 0x01000000
  * All errors moved to fatal
  * Vulnerability fixes
  * Improved robustness against ill-formed profiles
- Source and tools package renamed to lcms.
- Package split according to library packaging rules.
* Tue Feb  6 2007 ltinkl@suse.cz
- version 1.16
  * Improved stability.
  * Faster
  * Two different types of black preservation on CMYK-> CMYK transforms
  * Ability to set adaptation state of observer on absolute colorimetric transforms.
  * Actually it only allows No adaptation (d=0) and observer fully adapted (d=1)
  * lcms can now "fix" some broken 8-bit profiles that have gray axes misplaced.
  * icctrans can now read and write CGATS/IT8 files.
  * improved tifficc with tiff Lab8 support
  * icclink now supports colorant table tag.
  * pthread support
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 16 2005 ltinkl@suse.cz
- update to 1.15
* Wed Jan  5 2005 adrian@suse.de
- update to version 1.14
- add c++ packages to nfb, libtiff does use c++ now.
* Sun Dec 21 2003 adrian@suse.de
- update to version 1.12
* Mon Oct 27 2003 ro@suse.de
- update to 1.11
* Sat Jul 19 2003 adrian@suse.de
- update to version 1.10
* Fri Feb 21 2003 ro@suse.de
- added provides liblcms.so to devel package (compat reasons)
* Thu Dec 19 2002 coolo@suse.de
- fixing soname of the library
* Thu Dec 19 2002 kukuk@suse.de
- Fix requires of main package in devel subpackage (add version)
* Wed Dec 18 2002 adrian@suse.de
- split -devel package
* Tue Aug  6 2002 adrian@suse.de
- add %%run_ldconfig
* Wed Jul 10 2002 adrian@suse.de
- update to version 1.09:
  Overall faster speed.
    Much better absolute colorimetric intents. LittleCMS does now 'undo'
    chromatic adaptation as recommended by latest ICC spec.
    Full softproofing.
    Full gamutchecking.
    Writting capabilities. Lcms can now create profiles as well.
    New CIE94, CMC and BFD color difference spaces.
    Low-level LUT handling is now promoted to API and documented.
    Parametric curves.
    Several ICC 4.0 extensions. Full ICC 4.0 compliance is expected on next
    revision.
    Improved WhiteBlack compensation
    Improved portability. Several new platforms added.
    New JPEGICC utility.
    Improved TIFFICC and ICCTRANS utilities.
    Some minor bugs fixed.
- The "some minor bug fixes" obsolete the big qt namespace fix.
* Mon Jun 24 2002 adrian@suse.de
- fix HANDLE statement in lcms.h for Qt3
* Fri Jun 21 2002 ro@suse.de
- use -fPIC for shared lib
- autodetect alpha
- autodetect bigendian
* Tue Jan 29 2002 adrian@suse.de
- update to version 1.08
- header files are moving from /usr/include/lcms to /usr/include
* Wed Jan 23 2002 coolo@suse.de
- add a soname to the library
* Fri Jan 11 2002 schwab@suse.de
- Make portable across architectures.
* Mon Jan  7 2002 adrian@suse.de
- use build root
- use %%{_libdir}
* Sun Nov 25 2001 adrian@suse.de
- add mips to big endian architectures
* Thu Oct 25 2001 ro@suse.de
- use mieee to make it build on alpha
* Mon Jul 16 2001 adrian@suse.de
- compile with -fPIC (fixed by kraxel)
* Fri Jun 15 2001 adrian@suse.de
- add s390x to big_endian
* Sun Mar 25 2001 adrian@suse.de
- update to 1.07. no libtool support anymore in the package :-(
* Wed Feb 28 2001 ro@suse.de
- don't talk about long if a 32bit type is desired ...
* Fri Feb  9 2001 bk@suse.de
- configure fixed to proper use of RPM_OPT_FLAGS
- fixed filelist (remove obsolete %%docdirs that are in aaa_base)
- move update_config macro to %%prep, before patches(is preparing)
* Wed Nov 29 2000 adrian@suse.de
- comment out PACKAGE and VERSION in lcms.h. this had break every
  configure test.
* Wed Oct  4 2000 adrian@suse.de
- Spec file created from lcms-1.06.tar.bz2 by autospec
